==> haskell-lifted-async-0.11.0-81-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.11.0
visibility:           public
id:                   lifted-async-0.11.0-LshGdlAzxQp43RtlU7idG
key:                  lifted-async-0.11.0-LshGdlAzxQp43RtlU7idG
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2025 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  2a3a607e93f57c17404b76db7c04765f
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.11.0-LshGdlAzxQp43RtlU7idG
depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    constraints-0.14.2-5Hasiz3qGyu5OkYwKIAmXY
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.11.0-85-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.11.0
visibility:           public
id:                   lifted-async-0.11.0-DvLFg7aKgzC77xUHNxZEMb
key:                  lifted-async-0.11.0-DvLFg7aKgzC77xUHNxZEMb
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2025 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  0d12e1621815b059373c524fe4515d18
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.11.0-DvLFg7aKgzC77xUHNxZEMb
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    constraints-0.14.2-HITsp0guL9Z2vC96u1IEz
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
